# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_stock_pull.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import kaisaglobalapi.py_protoc.msg_stock_common_pb2 as msg__stock__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_stock_pull.proto',
  package='MsgStockPull',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.message\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14msg_stock_pull.proto\x12\x0cMsgStockPull\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16msg_stock_common.proto\"\xad\x02\n\x11SubMarketPlateReq\x12&\n\x06market\x18\x01 \x01(\x0e\x32\x16.MsgStockCommon.Market\x12*\n\x08language\x18\x02 \x01(\x0e\x32\x18.MsgStockCommon.Language\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .MsgStockCommon.SubscriptionType\x12\x19\n\x11subMarketCodeList\x18\x04 \x03(\t\x12\x15\n\rshowAllDetail\x18\x05 \x01(\r\x12\x0e\n\x06sorted\x18\x06 \x01(\r\x12\x33\n\x0bsortedFiled\x18\x07 \x03(\x0e\x32\x1e.MsgStockPull.QuotaSortedFiled\x12\x0f\n\x07\x63urrent\x18\x08 \x01(\r\x12\x0c\n\x04size\x18\t \x01(\r\"l\n\x12\x42\x61sicMarketInfoReq\x12&\n\x06market\x18\x01 \x01(\x0e\x32\x16.MsgStockCommon.Market\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .MsgStockCommon.SubscriptionType\">\n\x10HandicapQuotaReq\x12*\n\tstockCode\x18\x01 \x03(\x0b\x32\x17.MsgStockPull.StockCode\"m\n\tStockCode\x12&\n\x06market\x18\x01 \x01(\x0e\x32\x16.MsgStockCommon.Market\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12*\n\x08language\x18\x03 \x01(\x0e\x32\x18.MsgStockCommon.Language\"\xfe\x02\n\nWarrantReq\x12\x13\n\x0bwarrantType\x18\x01 \x01(\r\x12\x17\n\x0fmaturityDayType\x18\x02 \x01(\r\x12\x13\n\x0b\x63ompanyCode\x18\x03 \x01(\r\x12\x15\n\rmoneynessType\x18\x04 \x01(\r\x12\x11\n\tstrikeMin\x18\x05 \x01(\t\x12\x11\n\tstrikeMax\x18\x06 \x01(\t\x12\x12\n\npremiumMin\x18\x07 \x01(\t\x12\x12\n\npremiumMax\x18\x08 \x01(\t\x12\x19\n\x11percOfStillOutMin\x18\t \x01(\t\x12\x19\n\x11percOfStillOutMax\x18\n \x01(\t\x12\x0e\n\x06sorted\x18\x0b \x01(\r\x12\x33\n\x0bsortedFiled\x18\x0c \x03(\x0e\x32\x1e.MsgStockPull.QuotaSortedFiled\x12\x0f\n\x07\x63urrent\x18\r \x01(\r\x12\x0c\n\x04size\x18\x0e \x01(\r\x12.\n\x04type\x18\x0f \x01(\x0e\x32 .MsgStockCommon.SubscriptionType\"w\n\x16SubMarketAssetInfoResp\x12&\n\x06market\x18\x01 \x01(\x0e\x32\x16.MsgStockCommon.Market\x12\x35\n\x0epagePlateQuota\x18\x02 \x03(\x0b\x32\x1d.MsgStockPull.IPagePlateQuota\"G\n\x11HandicapQuotaResp\x12\x32\n\rhandicapQuota\x18\x01 \x03(\x0b\x32\x1b.MsgStockPull.HandicapQuota\"\xeb\x01\n\rHandicapQuota\x12\x0f\n\x07\x61ssetId\x18\x02 \x01(\t\x12/\n\tassetInfo\x18\x03 \x01(\x0b\x32\x1c.MsgStockPull.BasicAssetInfo\x12\x33\n\x0b\x66inanceInfo\x18\x05 \x01(\x0b\x32\x1e.MsgStockPull.BasicFinanceInfo\x12/\n\tquoteInfo\x18\x06 \x01(\x0b\x32\x1c.MsgStockPull.BasicQuoteInfo\x12\x32\n\rotherQuotaExt\x18\x07 \x01(\x0b\x32\x1b.MsgStockPull.OtherQuotaExt\"\xb1\x01\n\x13\x42\x61sicMarketInfoResp\x12&\n\x06market\x18\x01 \x01(\x0e\x32\x16.MsgStockCommon.Market\x12\x34\n\x0e\x62\x61sicAssetInfo\x18\x03 \x03(\x0b\x32\x1c.MsgStockPull.BasicAssetInfo\x12<\n\x12\x62\x61sicSubMarketInfo\x18\x04 \x03(\x0b\x32 .MsgStockPull.BasicSubMarketInfo\"n\n\x0bWarrantResp\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x03 \x01(\r\x12,\n\x07warrant\x18\x04 \x03(\x0b\x32\x1b.MsgStockPull.WarrantDetail\"\xd9\x04\n\rWarrantDetail\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0b\n\x03now\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x0e\n\x06\x63hange\x18\x04 \x01(\t\x12\x11\n\tchangePct\x18\x05 \x01(\t\x12\x0e\n\x06volume\x18\x06 \x01(\t\x12\x10\n\x08tradeDay\x18\x07 \x01(\t\x12\x13\n\x0blastTradeDy\x18\x08 \x01(\t\x12\r\n\x05\x64\x65lta\x18\t \x01(\t\x12\x14\n\x0ctargetCprice\x18\n \x01(\t\x12\x16\n\x0e\x62reakEvenPrice\x18\x0b \x01(\t\x12\x0f\n\x07premium\x18\x0c \x01(\t\x12\x13\n\x0bmaturityDay\x18\r \x01(\t\x12\x16\n\x0epercOfStillOut\x18\x0e \x01(\t\x12\x12\n\nstillOutNo\x18\x0f \x01(\t\x12\x0e\n\x06strike\x18\x10 \x01(\t\x12\x10\n\x08\x65ntRatio\x18\x11 \x01(\t\x12\x17\n\x0fimplyVolatility\x18\x12 \x01(\t\x12\x11\n\tpstrPrice\x18\x13 \x01(\t\x12\x11\n\tmoneyness\x18\x14 \x01(\t\x12\x15\n\rleverageRatio\x18\x15 \x01(\t\x12\x18\n\x10\x65\x66\x66\x65\x63tiveGearing\x18\x16 \x01(\t\x12\x1a\n\x12\x65xercisePriceFloor\x18\x17 \x01(\t\x12\x1c\n\x14\x65xercisePriceCeiling\x18\x18 \x01(\t\x12\x18\n\x10warrantCharacter\x18\x19 \x01(\t\x12\x13\n\x0b\x63ompanyCode\x18\x1a \x01(\t\x12\x0e\n\x06issuer\x18\x1b \x01(\t\x12\x10\n\x08issueVol\x18\x1c \x01(\t\x12\x14\n\x0cminTradeSize\x18\x1d \x01(\t\"\xb9\x01\n\x0fIPagePlateQuota\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x04 \x01(\r\x12\x15\n\rsubMarketCode\x18\x05 \x01(\t\x12.\n\x04type\x18\x06 \x01(\x0e\x32 .MsgStockCommon.SubscriptionType\x12,\n\nplateQuota\x18\x07 \x03(\x0b\x32\x18.MsgStockPull.PlateQuota\"\xb7\x01\n\nPlateQuota\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12.\n\x0b\x63ommonQuota\x18\x02 \x01(\x0b\x32\x19.MsgStockPull.CommonQuota\x12\x30\n\x0cpopularQuota\x18\x03 \x01(\x0b\x32\x1a.MsgStockPull.PopularQuota\x12\x36\n\x0fsimpleAssetInfo\x18\x04 \x01(\x0b\x32\x1d.MsgStockPull.SimpleAssetInfo\"\xab\x01\n\x0cPopularQuota\x12\x12\n\nsubPlateId\x18\x01 \x01(\t\x12\x14\n\x0csubPlateCode\x18\x02 \x01(\t\x12\x14\n\x0csubPlateName\x18\x03 \x01(\t\x12\x11\n\tchangePct\x18\x04 \x01(\t\x12\x0e\n\x06\x63hange\x18\x05 \x01(\t\x12\x0f\n\x07stkCode\x18\x06 \x01(\t\x12\x11\n\tshortName\x18\x07 \x01(\t\x12\x14\n\x0c\x61vgChangePct\x18\x08 \x01(\t\"\xc2\x01\n\x0b\x43ommonQuota\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x30\n\nbasicQuote\x18\x02 \x01(\x0b\x32\x1c.MsgStockPull.BasicQuoteInfo\x12<\n\x12\x63ommonFinanceQuota\x18\x03 \x01(\x0b\x32 .MsgStockPull.CommonFinanceQuota\x12\x32\n\rotherQuotaExt\x18\x04 \x01(\x0b\x32\x1b.MsgStockPull.OtherQuotaExt\"[\n\rOtherQuotaExt\x12\x11\n\touterDisk\x18\x01 \x01(\t\x12\x11\n\tinnerDisk\x18\x02 \x01(\t\x12\x11\n\trisePrice\x18\x03 \x01(\t\x12\x11\n\tfallPrice\x18\x04 \x01(\t\"\xe1\x01\n\x10\x42\x61sicFinanceInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x14\n\x0cshareCapital\x18\x02 \x01(\t\x12\x1a\n\x12\x63irculationCapital\x18\x03 \x01(\t\x12\x19\n\x11\x65\x61rningsPerShares\x18\x04 \x01(\t\x12\x12\n\nnetAssetPS\x18\x05 \x01(\t\x12\x1d\n\x15\x64ividendPerShareTotal\x18\x06 \x01(\t\x12<\n\x12\x63ommonFinanceQuota\x18\x07 \x01(\x0b\x32 .MsgStockPull.CommonFinanceQuota\"\xbb\x02\n\x12\x43ommonFinanceQuota\x12\x13\n\x0bmarketValue\x18\x01 \x01(\t\x12\x14\n\x0cturnoverRate\x18\x02 \x01(\t\x12\x0f\n\x07peRatio\x18\x03 \x01(\t\x12\x12\n\npeRatioTTM\x18\x04 \x01(\t\x12\x0f\n\x07pbRatio\x18\x05 \x01(\t\x12\x15\n\rquantityRatio\x18\x06 \x01(\t\x12\x11\n\tcommittee\x18\x07 \x01(\t\x12\x11\n\tamplitude\x18\x08 \x01(\t\x12\x17\n\x0fnegotiableValue\x18\t \x01(\t\x12\x18\n\x10\x64ividendPerShare\x18\n \x01(\t\x12\x15\n\rdividendRatio\x18\x0b \x01(\t\x12\x12\n\nchangeRate\x18\x0c \x01(\t\x12\x14\n\x0chighIn52Week\x18\r \x01(\t\x12\x13\n\x0blowIn52Week\x18\x0e \x01(\t\"\x89\x02\n\x0e\x42\x61sicQuoteInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0b\n\x03now\x18\x02 \x01(\t\x12\x0c\n\x04open\x18\x03 \x01(\t\x12\x0c\n\x04high\x18\x04 \x01(\t\x12\x0b\n\x03low\x18\x05 \x01(\t\x12\x11\n\tlastClose\x18\x06 \x01(\t\x12\x0e\n\x06volume\x18\x07 \x01(\t\x12\x0e\n\x06\x61mount\x18\x08 \x01(\t\x12\x10\n\x08\x61vgPrice\x18\t \x01(\t\x12 \n\x18perVolumeInLast5TradeDay\x18\n \x01(\t\x12\x11\n\tchangePct\x18\x0b \x01(\t\x12\x0e\n\x06\x63hange\x18\x0c \x01(\t\x12\x13\n\x0bstockStatus\x18\r \x01(\r\x12\x11\n\tstockTime\x18\x0e \x01(\t\"\x86\x02\n\x0e\x42\x61sicAssetInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x11\n\tshortName\x18\x02 \x01(\t\x12\x0f\n\x07stkCode\x18\x03 \x01(\t\x12\x0f\n\x07lotSize\x18\x04 \x01(\t\x12\x12\n\nstatusFlag\x18\x05 \x01(\t\x12\x13\n\x0blistingDate\x18\x06 \x01(\t\x12\x15\n\rdelistingDate\x18\x07 \x01(\t\x12\x14\n\x0cpriceDecimal\x18\x08 \x01(\r\x12\x15\n\rsubMarketCode\x18\t \x01(\t\x12\x15\n\rsubMarketName\x18\n \x01(\t\x12\x14\n\x0c\x65xchangeCode\x18\x0b \x01(\t\x12\x14\n\x0c\x65xchangeName\x18\x0c \x01(\t\"R\n\x0fSimpleAssetInfo\x12\x11\n\tshortName\x18\x01 \x01(\t\x12\x15\n\rsubMarketCode\x18\x02 \x01(\r\x12\x15\n\rsubMarketName\x18\x03 \x01(\t\"\x95\x01\n\x11\x42\x61sicAssetInfoExt\x12\x15\n\rsubMarketCode\x18\x01 \x01(\r\x12\x15\n\rsubMarketName\x18\x02 \x01(\t\x12\x12\n\nmarketCode\x18\x03 \x01(\r\x12\x12\n\nmarketName\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangeCode\x18\x05 \x01(\t\x12\x14\n\x0c\x65xchangeName\x18\x06 \x01(\t\"\xbc\x01\n\x12\x42\x61sicSubMarketInfo\x12\x12\n\nmarketName\x18\x02 \x01(\t\x12\x15\n\rsubMarketCode\x18\x03 \x01(\t\x12\x15\n\rsubMarketName\x18\x04 \x01(\t\x12\x17\n\x0fsubMarketEnName\x18\x05 \x01(\t\x12\x17\n\x0fSubMarketTrName\x18\x06 \x01(\t\x12\x32\n\rsubMarketTime\x18\x07 \x01(\x0b\x32\x1b.MsgStockPull.SubMarketTime\"z\n\rSubMarketTime\x12\r\n\x05\x63lear\x18\x01 \x01(\r\x12\x0c\n\x04open\x18\x02 \x01(\r\x12\x11\n\ttime_zone\x18\x03 \x01(\r\x12*\n\ttradeTime\x18\x04 \x03(\x0b\x32\x17.MsgStockPull.TradeTime\x12\r\n\x05\x63lose\x18\x05 \x01(\r\"3\n\tTradeTime\x12\x13\n\x0btrade_start\x18\x01 \x01(\r\x12\x11\n\ttrade_end\x18\x02 \x01(\r*\xd1\x03\n\x10QuotaSortedFiled\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03now\x10\x01\x12\r\n\tchangePct\x10\x02\x12\n\n\x06\x63hange\x10\x03\x12\x0e\n\nchangeRate\x10\x04\x12\n\n\x06volume\x10\x05\x12\n\n\x06\x61mount\x10\x06\x12\x10\n\x0cturnoverRate\x10\x07\x12\x0b\n\x07peRatio\x10\x08\x12\x0b\n\x07pbRatio\x10\t\x12\r\n\tamplitude\x10\n\x12\x13\n\x0fnegotiableValue\x10\x0b\x12\x0f\n\x0bmarketValue\x10\x0c\x12\x11\n\rquantityRatio\x10\r\x12\r\n\tcommittee\x10\x0e\x12\x0f\n\x0bmaturityDay\x10\x0f\x12\n\n\x06strike\x10\x10\x12\x14\n\x10\x65\x66\x66\x65\x63tiveGearing\x10\x11\x12\x11\n\rleverageRatio\x10\x12\x12\x0b\n\x07premium\x10\x13\x12\r\n\tpstrPrice\x10\x14\x12\r\n\tmoneyness\x10\x15\x12\x12\n\x0epercOfStillOut\x10\x16\x12\x16\n\x12\x65xercisePriceFloor\x10\x17\x12\x18\n\x14\x65xercisePriceCeiling\x10\x18\x12\x13\n\x0fimplyVolatility\x10\x19\x12\x0c\n\x08\x65ntRatio\x10\x1a\x12\n\n\x06status\x10\x1b\x42.\n#com.kaisaglobal.proto.stock.message\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,msg__stock__common__pb2.DESCRIPTOR,])

_QUOTASORTEDFILED = _descriptor.EnumDescriptor(
  name='QuotaSortedFiled',
  full_name='MsgStockPull.QuotaSortedFiled',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='now', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='change', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changeRate', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='volume', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amount', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='turnoverRate', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='peRatio', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pbRatio', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amplitude', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='negotiableValue', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='marketValue', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='quantityRatio', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='committee', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='maturityDay', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='strike', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='effectiveGearing', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='leverageRatio', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='premium', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pstrPrice', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='moneyness', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='percOfStillOut', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='exercisePriceFloor', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='exercisePriceCeiling', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='implyVolatility', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='entRatio', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='status', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4919,
  serialized_end=5384,
)
_sym_db.RegisterEnumDescriptor(_QUOTASORTEDFILED)

QuotaSortedFiled = enum_type_wrapper.EnumTypeWrapper(_QUOTASORTEDFILED)
NONE = 0
now = 1
changePct = 2
change = 3
changeRate = 4
volume = 5
amount = 6
turnoverRate = 7
peRatio = 8
pbRatio = 9
amplitude = 10
negotiableValue = 11
marketValue = 12
quantityRatio = 13
committee = 14
maturityDay = 15
strike = 16
effectiveGearing = 17
leverageRatio = 18
premium = 19
pstrPrice = 20
moneyness = 21
percOfStillOut = 22
exercisePriceFloor = 23
exercisePriceCeiling = 24
implyVolatility = 25
entRatio = 26
status = 27



_SUBMARKETPLATEREQ = _descriptor.Descriptor(
  name='SubMarketPlateReq',
  full_name='MsgStockPull.SubMarketPlateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.SubMarketPlateReq.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='MsgStockPull.SubMarketPlateReq.language', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockPull.SubMarketPlateReq.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCodeList', full_name='MsgStockPull.SubMarketPlateReq.subMarketCodeList', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showAllDetail', full_name='MsgStockPull.SubMarketPlateReq.showAllDetail', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sorted', full_name='MsgStockPull.SubMarketPlateReq.sorted', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortedFiled', full_name='MsgStockPull.SubMarketPlateReq.sortedFiled', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.SubMarketPlateReq.current', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.SubMarketPlateReq.size', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=397,
)


_BASICMARKETINFOREQ = _descriptor.Descriptor(
  name='BasicMarketInfoReq',
  full_name='MsgStockPull.BasicMarketInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.BasicMarketInfoReq.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockPull.BasicMarketInfoReq.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=507,
)


_HANDICAPQUOTAREQ = _descriptor.Descriptor(
  name='HandicapQuotaReq',
  full_name='MsgStockPull.HandicapQuotaReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.HandicapQuotaReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=571,
)


_STOCKCODE = _descriptor.Descriptor(
  name='StockCode',
  full_name='MsgStockPull.StockCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.StockCode.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.StockCode.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='MsgStockPull.StockCode.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=682,
)


_WARRANTREQ = _descriptor.Descriptor(
  name='WarrantReq',
  full_name='MsgStockPull.WarrantReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warrantType', full_name='MsgStockPull.WarrantReq.warrantType', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturityDayType', full_name='MsgStockPull.WarrantReq.maturityDayType', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyCode', full_name='MsgStockPull.WarrantReq.companyCode', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moneynessType', full_name='MsgStockPull.WarrantReq.moneynessType', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikeMin', full_name='MsgStockPull.WarrantReq.strikeMin', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikeMax', full_name='MsgStockPull.WarrantReq.strikeMax', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premiumMin', full_name='MsgStockPull.WarrantReq.premiumMin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premiumMax', full_name='MsgStockPull.WarrantReq.premiumMax', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOutMin', full_name='MsgStockPull.WarrantReq.percOfStillOutMin', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOutMax', full_name='MsgStockPull.WarrantReq.percOfStillOutMax', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sorted', full_name='MsgStockPull.WarrantReq.sorted', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortedFiled', full_name='MsgStockPull.WarrantReq.sortedFiled', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.WarrantReq.current', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.WarrantReq.size', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockPull.WarrantReq.type', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=1067,
)


_SUBMARKETASSETINFORESP = _descriptor.Descriptor(
  name='SubMarketAssetInfoResp',
  full_name='MsgStockPull.SubMarketAssetInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.SubMarketAssetInfoResp.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagePlateQuota', full_name='MsgStockPull.SubMarketAssetInfoResp.pagePlateQuota', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1188,
)


_HANDICAPQUOTARESP = _descriptor.Descriptor(
  name='HandicapQuotaResp',
  full_name='MsgStockPull.HandicapQuotaResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handicapQuota', full_name='MsgStockPull.HandicapQuotaResp.handicapQuota', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1261,
)


_HANDICAPQUOTA = _descriptor.Descriptor(
  name='HandicapQuota',
  full_name='MsgStockPull.HandicapQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.HandicapQuota.assetId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetInfo', full_name='MsgStockPull.HandicapQuota.assetInfo', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='financeInfo', full_name='MsgStockPull.HandicapQuota.financeInfo', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteInfo', full_name='MsgStockPull.HandicapQuota.quoteInfo', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otherQuotaExt', full_name='MsgStockPull.HandicapQuota.otherQuotaExt', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1264,
  serialized_end=1499,
)


_BASICMARKETINFORESP = _descriptor.Descriptor(
  name='BasicMarketInfoResp',
  full_name='MsgStockPull.BasicMarketInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.BasicMarketInfoResp.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicAssetInfo', full_name='MsgStockPull.BasicMarketInfoResp.basicAssetInfo', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicSubMarketInfo', full_name='MsgStockPull.BasicMarketInfoResp.basicSubMarketInfo', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1679,
)


_WARRANTRESP = _descriptor.Descriptor(
  name='WarrantResp',
  full_name='MsgStockPull.WarrantResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.WarrantResp.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.WarrantResp.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.WarrantResp.totalCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrant', full_name='MsgStockPull.WarrantResp.warrant', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1681,
  serialized_end=1791,
)


_WARRANTDETAIL = _descriptor.Descriptor(
  name='WarrantDetail',
  full_name='MsgStockPull.WarrantDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.WarrantDetail.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockPull.WarrantDetail.now', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.WarrantDetail.amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.WarrantDetail.change', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.WarrantDetail.changePct', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.WarrantDetail.volume', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradeDay', full_name='MsgStockPull.WarrantDetail.tradeDay', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTradeDy', full_name='MsgStockPull.WarrantDetail.lastTradeDy', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta', full_name='MsgStockPull.WarrantDetail.delta', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetCprice', full_name='MsgStockPull.WarrantDetail.targetCprice', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='breakEvenPrice', full_name='MsgStockPull.WarrantDetail.breakEvenPrice', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premium', full_name='MsgStockPull.WarrantDetail.premium', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturityDay', full_name='MsgStockPull.WarrantDetail.maturityDay', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOut', full_name='MsgStockPull.WarrantDetail.percOfStillOut', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stillOutNo', full_name='MsgStockPull.WarrantDetail.stillOutNo', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strike', full_name='MsgStockPull.WarrantDetail.strike', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entRatio', full_name='MsgStockPull.WarrantDetail.entRatio', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implyVolatility', full_name='MsgStockPull.WarrantDetail.implyVolatility', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pstrPrice', full_name='MsgStockPull.WarrantDetail.pstrPrice', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moneyness', full_name='MsgStockPull.WarrantDetail.moneyness', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leverageRatio', full_name='MsgStockPull.WarrantDetail.leverageRatio', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effectiveGearing', full_name='MsgStockPull.WarrantDetail.effectiveGearing', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercisePriceFloor', full_name='MsgStockPull.WarrantDetail.exercisePriceFloor', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercisePriceCeiling', full_name='MsgStockPull.WarrantDetail.exercisePriceCeiling', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrantCharacter', full_name='MsgStockPull.WarrantDetail.warrantCharacter', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyCode', full_name='MsgStockPull.WarrantDetail.companyCode', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='MsgStockPull.WarrantDetail.issuer', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issueVol', full_name='MsgStockPull.WarrantDetail.issueVol', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minTradeSize', full_name='MsgStockPull.WarrantDetail.minTradeSize', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=2395,
)


_IPAGEPLATEQUOTA = _descriptor.Descriptor(
  name='IPagePlateQuota',
  full_name='MsgStockPull.IPagePlateQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.IPagePlateQuota.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.IPagePlateQuota.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.IPagePlateQuota.totalCount', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.IPagePlateQuota.subMarketCode', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockPull.IPagePlateQuota.type', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plateQuota', full_name='MsgStockPull.IPagePlateQuota.plateQuota', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2398,
  serialized_end=2583,
)


_PLATEQUOTA = _descriptor.Descriptor(
  name='PlateQuota',
  full_name='MsgStockPull.PlateQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.PlateQuota.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonQuota', full_name='MsgStockPull.PlateQuota.commonQuota', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='popularQuota', full_name='MsgStockPull.PlateQuota.popularQuota', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simpleAssetInfo', full_name='MsgStockPull.PlateQuota.simpleAssetInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2769,
)


_POPULARQUOTA = _descriptor.Descriptor(
  name='PopularQuota',
  full_name='MsgStockPull.PopularQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subPlateId', full_name='MsgStockPull.PopularQuota.subPlateId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPlateCode', full_name='MsgStockPull.PopularQuota.subPlateCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPlateName', full_name='MsgStockPull.PopularQuota.subPlateName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.PopularQuota.changePct', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.PopularQuota.change', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stkCode', full_name='MsgStockPull.PopularQuota.stkCode', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.PopularQuota.shortName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgChangePct', full_name='MsgStockPull.PopularQuota.avgChangePct', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=2943,
)


_COMMONQUOTA = _descriptor.Descriptor(
  name='CommonQuota',
  full_name='MsgStockPull.CommonQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.CommonQuota.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicQuote', full_name='MsgStockPull.CommonQuota.basicQuote', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonFinanceQuota', full_name='MsgStockPull.CommonQuota.commonFinanceQuota', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otherQuotaExt', full_name='MsgStockPull.CommonQuota.otherQuotaExt', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2946,
  serialized_end=3140,
)


_OTHERQUOTAEXT = _descriptor.Descriptor(
  name='OtherQuotaExt',
  full_name='MsgStockPull.OtherQuotaExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outerDisk', full_name='MsgStockPull.OtherQuotaExt.outerDisk', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='innerDisk', full_name='MsgStockPull.OtherQuotaExt.innerDisk', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='risePrice', full_name='MsgStockPull.OtherQuotaExt.risePrice', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallPrice', full_name='MsgStockPull.OtherQuotaExt.fallPrice', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3142,
  serialized_end=3233,
)


_BASICFINANCEINFO = _descriptor.Descriptor(
  name='BasicFinanceInfo',
  full_name='MsgStockPull.BasicFinanceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicFinanceInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shareCapital', full_name='MsgStockPull.BasicFinanceInfo.shareCapital', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='circulationCapital', full_name='MsgStockPull.BasicFinanceInfo.circulationCapital', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='earningsPerShares', full_name='MsgStockPull.BasicFinanceInfo.earningsPerShares', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='netAssetPS', full_name='MsgStockPull.BasicFinanceInfo.netAssetPS', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendPerShareTotal', full_name='MsgStockPull.BasicFinanceInfo.dividendPerShareTotal', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonFinanceQuota', full_name='MsgStockPull.BasicFinanceInfo.commonFinanceQuota', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3236,
  serialized_end=3461,
)


_COMMONFINANCEQUOTA = _descriptor.Descriptor(
  name='CommonFinanceQuota',
  full_name='MsgStockPull.CommonFinanceQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketValue', full_name='MsgStockPull.CommonFinanceQuota.marketValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnoverRate', full_name='MsgStockPull.CommonFinanceQuota.turnoverRate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peRatio', full_name='MsgStockPull.CommonFinanceQuota.peRatio', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peRatioTTM', full_name='MsgStockPull.CommonFinanceQuota.peRatioTTM', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pbRatio', full_name='MsgStockPull.CommonFinanceQuota.pbRatio', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantityRatio', full_name='MsgStockPull.CommonFinanceQuota.quantityRatio', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committee', full_name='MsgStockPull.CommonFinanceQuota.committee', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='MsgStockPull.CommonFinanceQuota.amplitude', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negotiableValue', full_name='MsgStockPull.CommonFinanceQuota.negotiableValue', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendPerShare', full_name='MsgStockPull.CommonFinanceQuota.dividendPerShare', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendRatio', full_name='MsgStockPull.CommonFinanceQuota.dividendRatio', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changeRate', full_name='MsgStockPull.CommonFinanceQuota.changeRate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highIn52Week', full_name='MsgStockPull.CommonFinanceQuota.highIn52Week', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowIn52Week', full_name='MsgStockPull.CommonFinanceQuota.lowIn52Week', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3464,
  serialized_end=3779,
)


_BASICQUOTEINFO = _descriptor.Descriptor(
  name='BasicQuoteInfo',
  full_name='MsgStockPull.BasicQuoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicQuoteInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockPull.BasicQuoteInfo.now', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.BasicQuoteInfo.open', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='MsgStockPull.BasicQuoteInfo.high', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='MsgStockPull.BasicQuoteInfo.low', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.BasicQuoteInfo.lastClose', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.BasicQuoteInfo.volume', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.BasicQuoteInfo.amount', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgPrice', full_name='MsgStockPull.BasicQuoteInfo.avgPrice', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perVolumeInLast5TradeDay', full_name='MsgStockPull.BasicQuoteInfo.perVolumeInLast5TradeDay', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.BasicQuoteInfo.changePct', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.BasicQuoteInfo.change', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stockStatus', full_name='MsgStockPull.BasicQuoteInfo.stockStatus', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stockTime', full_name='MsgStockPull.BasicQuoteInfo.stockTime', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3782,
  serialized_end=4047,
)


_BASICASSETINFO = _descriptor.Descriptor(
  name='BasicAssetInfo',
  full_name='MsgStockPull.BasicAssetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicAssetInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.BasicAssetInfo.shortName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stkCode', full_name='MsgStockPull.BasicAssetInfo.stkCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lotSize', full_name='MsgStockPull.BasicAssetInfo.lotSize', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusFlag', full_name='MsgStockPull.BasicAssetInfo.statusFlag', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listingDate', full_name='MsgStockPull.BasicAssetInfo.listingDate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delistingDate', full_name='MsgStockPull.BasicAssetInfo.delistingDate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priceDecimal', full_name='MsgStockPull.BasicAssetInfo.priceDecimal', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicAssetInfo.subMarketCode', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicAssetInfo.subMarketName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeCode', full_name='MsgStockPull.BasicAssetInfo.exchangeCode', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeName', full_name='MsgStockPull.BasicAssetInfo.exchangeName', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4050,
  serialized_end=4312,
)


_SIMPLEASSETINFO = _descriptor.Descriptor(
  name='SimpleAssetInfo',
  full_name='MsgStockPull.SimpleAssetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.SimpleAssetInfo.shortName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.SimpleAssetInfo.subMarketCode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.SimpleAssetInfo.subMarketName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4314,
  serialized_end=4396,
)


_BASICASSETINFOEXT = _descriptor.Descriptor(
  name='BasicAssetInfoExt',
  full_name='MsgStockPull.BasicAssetInfoExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicAssetInfoExt.subMarketCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicAssetInfoExt.subMarketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketCode', full_name='MsgStockPull.BasicAssetInfoExt.marketCode', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketName', full_name='MsgStockPull.BasicAssetInfoExt.marketName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeCode', full_name='MsgStockPull.BasicAssetInfoExt.exchangeCode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeName', full_name='MsgStockPull.BasicAssetInfoExt.exchangeName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4399,
  serialized_end=4548,
)


_BASICSUBMARKETINFO = _descriptor.Descriptor(
  name='BasicSubMarketInfo',
  full_name='MsgStockPull.BasicSubMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketName', full_name='MsgStockPull.BasicSubMarketInfo.marketName', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicSubMarketInfo.subMarketCode', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicSubMarketInfo.subMarketName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketEnName', full_name='MsgStockPull.BasicSubMarketInfo.subMarketEnName', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SubMarketTrName', full_name='MsgStockPull.BasicSubMarketInfo.SubMarketTrName', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketTime', full_name='MsgStockPull.BasicSubMarketInfo.subMarketTime', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4551,
  serialized_end=4739,
)


_SUBMARKETTIME = _descriptor.Descriptor(
  name='SubMarketTime',
  full_name='MsgStockPull.SubMarketTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear', full_name='MsgStockPull.SubMarketTime.clear', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.SubMarketTime.open', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='MsgStockPull.SubMarketTime.time_zone', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradeTime', full_name='MsgStockPull.SubMarketTime.tradeTime', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='MsgStockPull.SubMarketTime.close', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4741,
  serialized_end=4863,
)


_TRADETIME = _descriptor.Descriptor(
  name='TradeTime',
  full_name='MsgStockPull.TradeTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_start', full_name='MsgStockPull.TradeTime.trade_start', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_end', full_name='MsgStockPull.TradeTime.trade_end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4865,
  serialized_end=4916,
)

_SUBMARKETPLATEREQ.fields_by_name['market'].enum_type = msg__stock__common__pb2._MARKET
_SUBMARKETPLATEREQ.fields_by_name['language'].enum_type = msg__stock__common__pb2._LANGUAGE
_SUBMARKETPLATEREQ.fields_by_name['type'].enum_type = msg__stock__common__pb2._SUBSCRIPTIONTYPE
_SUBMARKETPLATEREQ.fields_by_name['sortedFiled'].enum_type = _QUOTASORTEDFILED
_BASICMARKETINFOREQ.fields_by_name['market'].enum_type = msg__stock__common__pb2._MARKET
_BASICMARKETINFOREQ.fields_by_name['type'].enum_type = msg__stock__common__pb2._SUBSCRIPTIONTYPE
_HANDICAPQUOTAREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_STOCKCODE.fields_by_name['market'].enum_type = msg__stock__common__pb2._MARKET
_STOCKCODE.fields_by_name['language'].enum_type = msg__stock__common__pb2._LANGUAGE
_WARRANTREQ.fields_by_name['sortedFiled'].enum_type = _QUOTASORTEDFILED
_WARRANTREQ.fields_by_name['type'].enum_type = msg__stock__common__pb2._SUBSCRIPTIONTYPE
_SUBMARKETASSETINFORESP.fields_by_name['market'].enum_type = msg__stock__common__pb2._MARKET
_SUBMARKETASSETINFORESP.fields_by_name['pagePlateQuota'].message_type = _IPAGEPLATEQUOTA
_HANDICAPQUOTARESP.fields_by_name['handicapQuota'].message_type = _HANDICAPQUOTA
_HANDICAPQUOTA.fields_by_name['assetInfo'].message_type = _BASICASSETINFO
_HANDICAPQUOTA.fields_by_name['financeInfo'].message_type = _BASICFINANCEINFO
_HANDICAPQUOTA.fields_by_name['quoteInfo'].message_type = _BASICQUOTEINFO
_HANDICAPQUOTA.fields_by_name['otherQuotaExt'].message_type = _OTHERQUOTAEXT
_BASICMARKETINFORESP.fields_by_name['market'].enum_type = msg__stock__common__pb2._MARKET
_BASICMARKETINFORESP.fields_by_name['basicAssetInfo'].message_type = _BASICASSETINFO
_BASICMARKETINFORESP.fields_by_name['basicSubMarketInfo'].message_type = _BASICSUBMARKETINFO
_WARRANTRESP.fields_by_name['warrant'].message_type = _WARRANTDETAIL
_IPAGEPLATEQUOTA.fields_by_name['type'].enum_type = msg__stock__common__pb2._SUBSCRIPTIONTYPE
_IPAGEPLATEQUOTA.fields_by_name['plateQuota'].message_type = _PLATEQUOTA
_PLATEQUOTA.fields_by_name['commonQuota'].message_type = _COMMONQUOTA
_PLATEQUOTA.fields_by_name['popularQuota'].message_type = _POPULARQUOTA
_PLATEQUOTA.fields_by_name['simpleAssetInfo'].message_type = _SIMPLEASSETINFO
_COMMONQUOTA.fields_by_name['basicQuote'].message_type = _BASICQUOTEINFO
_COMMONQUOTA.fields_by_name['commonFinanceQuota'].message_type = _COMMONFINANCEQUOTA
_COMMONQUOTA.fields_by_name['otherQuotaExt'].message_type = _OTHERQUOTAEXT
_BASICFINANCEINFO.fields_by_name['commonFinanceQuota'].message_type = _COMMONFINANCEQUOTA
_BASICSUBMARKETINFO.fields_by_name['subMarketTime'].message_type = _SUBMARKETTIME
_SUBMARKETTIME.fields_by_name['tradeTime'].message_type = _TRADETIME
DESCRIPTOR.message_types_by_name['SubMarketPlateReq'] = _SUBMARKETPLATEREQ
DESCRIPTOR.message_types_by_name['BasicMarketInfoReq'] = _BASICMARKETINFOREQ
DESCRIPTOR.message_types_by_name['HandicapQuotaReq'] = _HANDICAPQUOTAREQ
DESCRIPTOR.message_types_by_name['StockCode'] = _STOCKCODE
DESCRIPTOR.message_types_by_name['WarrantReq'] = _WARRANTREQ
DESCRIPTOR.message_types_by_name['SubMarketAssetInfoResp'] = _SUBMARKETASSETINFORESP
DESCRIPTOR.message_types_by_name['HandicapQuotaResp'] = _HANDICAPQUOTARESP
DESCRIPTOR.message_types_by_name['HandicapQuota'] = _HANDICAPQUOTA
DESCRIPTOR.message_types_by_name['BasicMarketInfoResp'] = _BASICMARKETINFORESP
DESCRIPTOR.message_types_by_name['WarrantResp'] = _WARRANTRESP
DESCRIPTOR.message_types_by_name['WarrantDetail'] = _WARRANTDETAIL
DESCRIPTOR.message_types_by_name['IPagePlateQuota'] = _IPAGEPLATEQUOTA
DESCRIPTOR.message_types_by_name['PlateQuota'] = _PLATEQUOTA
DESCRIPTOR.message_types_by_name['PopularQuota'] = _POPULARQUOTA
DESCRIPTOR.message_types_by_name['CommonQuota'] = _COMMONQUOTA
DESCRIPTOR.message_types_by_name['OtherQuotaExt'] = _OTHERQUOTAEXT
DESCRIPTOR.message_types_by_name['BasicFinanceInfo'] = _BASICFINANCEINFO
DESCRIPTOR.message_types_by_name['CommonFinanceQuota'] = _COMMONFINANCEQUOTA
DESCRIPTOR.message_types_by_name['BasicQuoteInfo'] = _BASICQUOTEINFO
DESCRIPTOR.message_types_by_name['BasicAssetInfo'] = _BASICASSETINFO
DESCRIPTOR.message_types_by_name['SimpleAssetInfo'] = _SIMPLEASSETINFO
DESCRIPTOR.message_types_by_name['BasicAssetInfoExt'] = _BASICASSETINFOEXT
DESCRIPTOR.message_types_by_name['BasicSubMarketInfo'] = _BASICSUBMARKETINFO
DESCRIPTOR.message_types_by_name['SubMarketTime'] = _SUBMARKETTIME
DESCRIPTOR.message_types_by_name['TradeTime'] = _TRADETIME
DESCRIPTOR.enum_types_by_name['QuotaSortedFiled'] = _QUOTASORTEDFILED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubMarketPlateReq = _reflection.GeneratedProtocolMessageType('SubMarketPlateReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETPLATEREQ,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketPlateReq)
  })
_sym_db.RegisterMessage(SubMarketPlateReq)

BasicMarketInfoReq = _reflection.GeneratedProtocolMessageType('BasicMarketInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _BASICMARKETINFOREQ,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicMarketInfoReq)
  })
_sym_db.RegisterMessage(BasicMarketInfoReq)

HandicapQuotaReq = _reflection.GeneratedProtocolMessageType('HandicapQuotaReq', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTAREQ,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuotaReq)
  })
_sym_db.RegisterMessage(HandicapQuotaReq)

StockCode = _reflection.GeneratedProtocolMessageType('StockCode', (_message.Message,), {
  'DESCRIPTOR' : _STOCKCODE,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.StockCode)
  })
_sym_db.RegisterMessage(StockCode)

WarrantReq = _reflection.GeneratedProtocolMessageType('WarrantReq', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTREQ,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantReq)
  })
_sym_db.RegisterMessage(WarrantReq)

SubMarketAssetInfoResp = _reflection.GeneratedProtocolMessageType('SubMarketAssetInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETASSETINFORESP,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketAssetInfoResp)
  })
_sym_db.RegisterMessage(SubMarketAssetInfoResp)

HandicapQuotaResp = _reflection.GeneratedProtocolMessageType('HandicapQuotaResp', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTARESP,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuotaResp)
  })
_sym_db.RegisterMessage(HandicapQuotaResp)

HandicapQuota = _reflection.GeneratedProtocolMessageType('HandicapQuota', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuota)
  })
_sym_db.RegisterMessage(HandicapQuota)

BasicMarketInfoResp = _reflection.GeneratedProtocolMessageType('BasicMarketInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _BASICMARKETINFORESP,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicMarketInfoResp)
  })
_sym_db.RegisterMessage(BasicMarketInfoResp)

WarrantResp = _reflection.GeneratedProtocolMessageType('WarrantResp', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTRESP,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantResp)
  })
_sym_db.RegisterMessage(WarrantResp)

WarrantDetail = _reflection.GeneratedProtocolMessageType('WarrantDetail', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTDETAIL,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantDetail)
  })
_sym_db.RegisterMessage(WarrantDetail)

IPagePlateQuota = _reflection.GeneratedProtocolMessageType('IPagePlateQuota', (_message.Message,), {
  'DESCRIPTOR' : _IPAGEPLATEQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.IPagePlateQuota)
  })
_sym_db.RegisterMessage(IPagePlateQuota)

PlateQuota = _reflection.GeneratedProtocolMessageType('PlateQuota', (_message.Message,), {
  'DESCRIPTOR' : _PLATEQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.PlateQuota)
  })
_sym_db.RegisterMessage(PlateQuota)

PopularQuota = _reflection.GeneratedProtocolMessageType('PopularQuota', (_message.Message,), {
  'DESCRIPTOR' : _POPULARQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.PopularQuota)
  })
_sym_db.RegisterMessage(PopularQuota)

CommonQuota = _reflection.GeneratedProtocolMessageType('CommonQuota', (_message.Message,), {
  'DESCRIPTOR' : _COMMONQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.CommonQuota)
  })
_sym_db.RegisterMessage(CommonQuota)

OtherQuotaExt = _reflection.GeneratedProtocolMessageType('OtherQuotaExt', (_message.Message,), {
  'DESCRIPTOR' : _OTHERQUOTAEXT,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.OtherQuotaExt)
  })
_sym_db.RegisterMessage(OtherQuotaExt)

BasicFinanceInfo = _reflection.GeneratedProtocolMessageType('BasicFinanceInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICFINANCEINFO,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicFinanceInfo)
  })
_sym_db.RegisterMessage(BasicFinanceInfo)

CommonFinanceQuota = _reflection.GeneratedProtocolMessageType('CommonFinanceQuota', (_message.Message,), {
  'DESCRIPTOR' : _COMMONFINANCEQUOTA,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.CommonFinanceQuota)
  })
_sym_db.RegisterMessage(CommonFinanceQuota)

BasicQuoteInfo = _reflection.GeneratedProtocolMessageType('BasicQuoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICQUOTEINFO,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicQuoteInfo)
  })
_sym_db.RegisterMessage(BasicQuoteInfo)

BasicAssetInfo = _reflection.GeneratedProtocolMessageType('BasicAssetInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICASSETINFO,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicAssetInfo)
  })
_sym_db.RegisterMessage(BasicAssetInfo)

SimpleAssetInfo = _reflection.GeneratedProtocolMessageType('SimpleAssetInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEASSETINFO,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SimpleAssetInfo)
  })
_sym_db.RegisterMessage(SimpleAssetInfo)

BasicAssetInfoExt = _reflection.GeneratedProtocolMessageType('BasicAssetInfoExt', (_message.Message,), {
  'DESCRIPTOR' : _BASICASSETINFOEXT,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicAssetInfoExt)
  })
_sym_db.RegisterMessage(BasicAssetInfoExt)

BasicSubMarketInfo = _reflection.GeneratedProtocolMessageType('BasicSubMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICSUBMARKETINFO,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicSubMarketInfo)
  })
_sym_db.RegisterMessage(BasicSubMarketInfo)

SubMarketTime = _reflection.GeneratedProtocolMessageType('SubMarketTime', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETTIME,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketTime)
  })
_sym_db.RegisterMessage(SubMarketTime)

TradeTime = _reflection.GeneratedProtocolMessageType('TradeTime', (_message.Message,), {
  'DESCRIPTOR' : _TRADETIME,
  '__module__' : 'msg_stock_pull_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TradeTime)
  })
_sym_db.RegisterMessage(TradeTime)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

# ===================================================================
# The contents of this file are dedicated to the public domain.  To
# the extent that dedication to the public domain is not available,
# everyone is granted a worldwide, perpetual, royalty-free,
# non-exclusive license to exercise all rights associated with the
# contents of this file for any purpose whatsoever.
# KaisaGlobal rights are reserved.
# ===================================================================

"""
This code provide utils function for KaisaGlobal-Open.

developed by KaisaGlobal quant team.
2020.12.11
"""


import numpy as np
import pandas as pd

import time
import datetime

def generate_datetime(timestamp: str) -> datetime:
    """"""
    if "." in timestamp:
        dt = datetime.strptime(timestamp, "%Y-%m-%d %H:%M:%S.%f")
    else:
        dt = datetime.strptime(timestamp, "%Y-%m-%d %H:%M:%S")
    return dt

def generate_timestamp():
    return str(int(time.time()*1000))

